alertsActor
==============================

a new alerts actor based off the twisted actor base

| |Build Status|
| |Coverage Status|

------------

This README describes the alertsActor Python package. It should include things like a general description, installation instructions, and requirements. It should also include information badges for other services or packages used, e.g., Travis-CI and Coveralls, ReadtheDocs, Astropy, etc.

.. |Build Status| image:: https://travis-ci.org/johndonor3/alertsActor.svg?branch=master
   :target: https://travis-ci.org/johndonor3/alertsActor

.. |Coverage Status| image:: https://coveralls.io/repos/github/johndonor3/alertsActor/badge.svg?branch=master
   :target: https://coveralls.io/github/johndonor3/alertsActor?branch=master
